@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Mobile.pm 288 2007-02-24 13:06:53Z hikarin $
+# $Id: Mobile.pm 538 2007-05-02 14:56:52Z hikarin $
 #
 
 package Img0ch::App::Mobile;
@@ -34,7 +34,7 @@ sub run {
     {
         my $filter = sub { ${ $_[0] } =~ tr/\n//d; ${ $_[0] } };
         if ( $iApp->{_param_key} ne '0000000000' ) {
-            $iApp->_load_thread(
+            $iApp->load_thread(
                 {},
                 {   filter   => $filter,
                     mobile   => 1,
@@ -44,28 +44,29 @@ sub run {
             );
         }
         else {
-            $iApp->_load_subject($filter);
+            $iApp->load_subject($filter);
         }
     }
     else {
-        $iApp->_redirect_error();
+        $iApp->redirect_error();
     }
 }
 
-sub _load_thread {
-    my ( $iApp, $template_vars, $option ) = @_;
+sub load_thread {
+    my ( $iApp, $template_vars, $option, $no_disk ) = @_;
     my $iConfig  = $iApp->{_config};
     my $iRequest = $iApp->{_request};
     my $server   = $iConfig->get('Server');
-    my $cgi      = $iConfig->get('CGIServer') || join('/', $server, 'test');
-    my $raw           = $iApp->{_param_raw};
-    my $renderer      = $iConfig->get('MobileRenderer') || 'r.cgi';
+    my $cgi      = $iRequest->get_app_uri();
+    my $raw      = $iApp->{_param_raw};
+    my $renderer = $iConfig->get('MobileRenderer') || 'r.cgi';
     my $setting_saved = $iApp->get_param('mode') eq 'SET';
     my $query         = $iRequest->query()
         || $iApp->{_query_with_extend_params};
     my ( $aas_path, $aas_dir ) = $server =~ m{http://(.+?)/(.*)?}xms;
 
     $query = Img0ch::Kernel::escape_html_entities($query);
+    $query =~ s/\A!+//xms;
     $query =~ s/&amp;/&/gxms;
     $query =~ s/&?mode=SET&?//xms;
     if ( ( $aas_dir || '' ) ne '' ) {
@@ -74,39 +75,54 @@ sub _load_thread {
         $aas_path .= '+' . $aas_dir;
     }
 
-    my $aas     = ($iApp->get_param('1a') || rindex( $raw, 'a' ) >= 0);
-    my $write   = rindex( $raw, 'w' ) >= 0   ? 1 : 0;
-    my $setting = rindex( $raw, 'SET' ) >= 0 ? 1 : 0;
-    my $is_form = $write || $setting || $setting_saved;
+    my $is_aas     = $iApp->get_param('1a')
+        || (rindex( $raw, 'a' ) >= 0 ? 1 : 0);
+    my $is_copy    = rindex( $raw, 'c' ) >= 0 ? 1 : 0;
+    my $is_setting = rindex( $raw, 'SET' ) >= 0 ? 1 : 0;
+    my $is_write   = rindex( $raw, 'w' ) >= 0   ? 1 : 0;
+    my $is_form    = $is_write || $is_setting || $setting_saved;
+    $option->{br2nl} = $is_copy;
+
+    my $name = $iApp->get_param('FROM');
+    if ($name) {
+        require Unicode::Japanese;
+        $name = Unicode::Japanese->new( $name, 'auto' )->sjis();
+    }
+    my $mail = $iApp->get_param('mail');
+    if ($mail) {
+        require Unicode::Japanese;
+        $mail = Unicode::Japanese->new( $mail, 'auto' )->sjis();
+    }
+
     %{$template_vars} = (
-        AAS             => ( $aas ? 1 : 0 ),
+        AAS => $is_aas,
         AASBase         => $aas_path,
         ALinkColor      => $iApp->get_param('alink'),
         BackGroundColor => $iApp->get_param('bgc'),
         BaseQueryString => ( $setting_saved ? '' : $query ),
         CR              => "\r",
-        Copy            => ( rindex( $raw, 'c' ) >= 0 ? 1 : 0 ),
+        Copy            => $is_copy,
         Fontsize        => $iApp->get_param_int('size'),
         KEY             => $iApp->{_param_key},
         LinkColor       => $iApp->get_param('link'),
-        NameByCookie    => $iApp->get_param('FROM'),
-        MailByCookie    => $iApp->get_param('mail'),
+        NameByCookie    => $name,
+        MailByCookie    => $mail,
         MailPostAddress => $iConfig->get('MailPostAddress'),
         QueryString     => $query,
         RCGIURI => join( '/', $cgi, $renderer ),
-        SettingForm => ( $setting and !$setting_saved ),
+        RawOption => $raw,
+        SettingForm => ( $is_setting and !$setting_saved ),
         SettingSaved => $setting_saved,
         TextColor    => $iApp->get_param('txt'),
         VLinkColor   => $iApp->get_param('vlink'),
         Write        => $is_form,
-        WriteForm    => $write,
+        WriteForm    => $is_write,
     );
-
-    $iApp->SUPER::_load_thread( $template_vars, $option );
+    $iApp->SUPER::load_thread( $template_vars, $option, $no_disk );
 }
 
-sub _load_subject {
-    my ( $iApp, $filter ) = @_;
+sub load_subject {
+    my ( $iApp, $filter, $no_disk ) = @_;
     my $iBBS     = $iApp->{_bbs};
     my $iRequest = $iApp->{_request};
     my $iSetting = $iApp->{_setting};
@@ -133,12 +149,12 @@ sub _load_subject {
         || $iSetting->get_int('BBS_MB_THREAD_NUMBER')
         || 1;
 
-    my $copy               = $raw =~ s/[cC]\z//xms ? 1 : 0;
+    my $copy = $raw =~ s/[cC]\z//xms ? 1 : 0;
     my $start              = Img0ch::Kernel::intval($raw) || 1;
     my $read_subject_stack = [];
     my $i                  = 1;
 
-    for my $subject ( @$found ) {
+    for my $subject (@$found) {
         if ( $i >= $start and $i < $start + $floatable ) {
             push @{$read_subject_stack},
                 {
@@ -161,38 +177,45 @@ sub _load_subject {
             setting => $iSetting,
         }
     );
-    my $iConfig  = $iApp->{_config};
-    my $query = $iRequest->query() || $iApp->{_query_with_extend_params};
-    my $server   = $iConfig->get('CGIServer')
-        || join('/', $iConfig->get('Server'), 'test');
-    my $renderer      = $iConfig->get('MobileRenderer') || 'r.cgi';
+    my $iConfig = $iApp->{_config};
 
-    $iTemplate->param(
-        {
-            ALinkColor      => $iApp->get_param('alink'),
-            BackGroundColor => $iApp->get_param('bgc'),
-            Banner  => $iMeta->mobile_banner(),
-            CR      => "\r",
-            Copy    => $copy,
-            Count   => $count,
-            Current => $start,
-            Fontsize => $iApp->get_param_int('size'),
-            From    => $start + 100,
-            MailByCookie    => $iApp->get_param('mail'),
-            NameByCookie    => $iApp->get_param('FROM'),
-            Next    => $start + $floatable,
-            Prev    => ( ( !$count or $prev > 0 ) ? $prev : 0 ),
-            QueryString     => $query,
-            RCGIURI => join( '/', $server, $renderer ),
-            Search  => $word,
-            TextColor    => $iApp->get_param('txt'),
-            Threads => $read_subject_stack,
-            VLinkColor   => $iApp->get_param('vlink'),
-            Write => ( rindex( $raw, 'w' ) >= 0 ? 1 : 0 ),
-        }
-    );
-    $iRequest->send_http_header('text/html');
-    $iTemplate->flush($filter);
+    my $query   = $iRequest->query() || $iApp->{_query_with_extend_params};
+    $query =~ s/\A!+//xms;
+
+    my $server = $iRequest->get_app_uri();
+    my $renderer = $iConfig->get('MobileRenderer') || 'r.cgi';
+    my $template_parameters = {
+        ALinkColor      => $iApp->get_param('alink'),
+        BackGroundColor => $iApp->get_param('bgc'),
+        Banner          => $iMeta->mobile_banner(),
+        CR              => "\r",
+        Copy            => $copy,
+        Count           => $count,
+        Current         => $start,
+        Fontsize        => $iApp->get_param_int('size'),
+        From            => $start + 100,
+        MailByCookie    => $iApp->get_param('mail'),
+        NameByCookie    => $iApp->get_param('FROM'),
+        Next            => $start + $floatable,
+        Prev            => ( ( !$count or $prev > 0 ) ? $prev : 0 ),
+        QueryString     => $query,
+        RCGIURI    => join( '/', $server, $renderer ),
+        Search     => $word,
+        TextColor  => $iApp->get_param('txt'),
+        Threads    => $read_subject_stack,
+        VLinkColor => $iApp->get_param('vlink'),
+        Write => ( rindex( $raw, 'w' ) >= 0 ? 1 : 0 ),
+    };
+
+    if ($no_disk) {
+        return $template_parameters;
+    }
+    else {
+        $iTemplate->param($template_parameters);
+        $iRequest->send_http_header('text/html');
+        $iTemplate->flush($filter);
+        return 1;
+    }
 }
 
 1;
